<?php
/**
 * KYBULLY functions and definitions
 *
 * Sets up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development
 * and http://codex.wordpress.org/Child_Themes), you can override certain
 * functions (those wrapped in a function_exists() call) by defining them first
 * in your child theme's functions.php file. The child theme's functions.php
 * file is included before the parent theme's file, so the child theme
 * functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, @link http://codex.wordpress.org/Plugin_API
 *
 * @package WordPress
 * @subpackage KYBULLY
 * @since KYBULLY 1.0
 */

/*
 * Set up the content width value based on the theme's design.
 *
 * @see kybully_content_width() for template-specific adjustments.
 */
if (! isset ( $content_width ))
	$content_width = 604;

/**
 * Add support for a custom header image.
 */
require get_template_directory () . '/inc/custom-header.php';

/**
 * KYBULLY only works in WordPress 3.6 or later.
 */
if (version_compare ( $GLOBALS ['wp_version'], '3.6-alpha', '<' ))
	require get_template_directory () . '/inc/back-compat.php';

/**
 * Detect plugin. For use on Front End only.
 */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

/**
 * KYBULLY setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * KYBULLY supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add Visual Editor stylesheets.
 * @uses add_theme_support() To add support for automatic feed links, post
 *       formats, and post thumbnails.
 * @uses register_nav_menu() To add support for a navigation menu.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *      
 * @since KYBULLY 1.0
 */
function kybully_setup() {
	

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on kybully, use a find and replace
	 * to change 'kybully' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'kybully', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 825, 510, true );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => __( 'Kybully MainMenu',      'kybully' ),
		'footer-menu'  => __( 'Kybully FooterMenu', 'kybully' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
	) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', 'genericons/genericons.css', kybully_fonts_url() ) );
} // kybully_setup
add_action ( 'after_setup_theme', 'kybully_setup' );

/**
 * Return the Google font stylesheet URL, if available.
 *
 * The use of Source Sans Pro and Bitter by default is localized. For languages
 * that use characters not supported by the font, the font can be disabled.
 *
 * @since KYBULLY 1.0
 *       
 * @return string Font stylesheet or empty string if disabled.
 */
function kybully_fonts_url() {
	$fonts_url = '';

	/*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
    */
	 
	if ( 'off' !== _x( 'on', 'Google font: on or off', 'kybully' ) ) {
		$fonts_url = add_query_arg( 'family' , urlencode('Asap:400,700,400italic,700italic'), "//fonts.googleapis.com/css" );
	}
	return $fonts_url;
}

/**
 * Filter the page title.
 *
 * Creates a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @since KYBULLY 1.0
 *       
 * @param string $title
 *        	Default title text for current view.
 * @param string $sep
 *        	Optional separator.
 * @return string The filtered title.
 */
function kybully_wp_title($title, $sep) {
	global $paged, $page;
	
	if (is_feed ())
		return $title;
		
		// Add the site name.
	$title .= get_bloginfo ( 'name', 'display' );
	
	// Add the site description for the home/front page.
	$site_description = get_bloginfo ( 'description', 'display' );
	if ($site_description && (is_home () || is_front_page ()))
		$title = "$title $sep $site_description";
		
		// Add a page number if necessary.
	if (($paged >= 2 || $page >= 2) && ! is_404 ())
		$title = "$title $sep " . sprintf ( __ ( 'Page %s', 'kybully' ), max ( $paged, $page ) );
	
	return $title;
}
add_filter ( 'wp_title', 'kybully_wp_title', 10, 2 );

/**
 * Register two widget areas.
 *
 * @since KYBULLY 1.0
 */
function kybully_widgets_init() {
	register_sidebar ( array (
			'name' => __ ( 'Main Widget Area', 'kybully' ),
			'id' => 'sidebar-1',
			'description' => __ ( 'Appears in the footer section of the site.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => ' <div class="widget-seperator"></div></aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Secondary Widget Area', 'kybully' ),
			'id' => 'sidebar-2',
			'description' => __ ( 'Appears on posts and pages in the sidebar.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '<div class="widget-seperator"></div> </aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Woocommerce Widget Area', 'kybully' ),
			'id' => 'sidebar-3',
			'description' => __ ( 'Appears on Woocommerce Widget in the sidebar.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '<div class="widget-seperator"></div></aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Navigation Widget Area', 'kybully' ),
			'id' => 'sidebar-4',
			'description' => __ ( 'Appears on Navigation Menu in sidebar.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '<div class="widget-seperator"></div> </aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Footer Widget Colunm1', 'kybully' ),
			'id' => 'footer-widget-1',
			'description' => __ ( 'Appears in the footer section of the site.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => ' </aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Footer Widget Colunm2', 'kybully' ),
			'id' => 'footer-widget-2',
			'description' => __ ( 'Appears in the footer section of the site.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => ' </aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Footer Widget Colunm3', 'kybully' ),
			'id' => 'footer-widget-3',
			'description' => __ ( 'Appears in the footer section of the site.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => ' </aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
	register_sidebar ( array (
			'name' => __ ( 'Footer Widget Colunm4', 'kybully' ),
			'id' => 'footer-widget-4',
			'description' => __ ( 'Appears in the footer section of the site.', 'kybully' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside> ',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>' 
	) );
}
add_action ( 'widgets_init', 'kybully_widgets_init' );


if (! function_exists ( 'kybully_paging_nav' )) :
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 *
	 * @since KYBULLY 1.0
	 */
	function kybully_paging_nav() {
		global $wp_query;
		
		// Don't print empty markup if there's only one page.
		if ($wp_query->max_num_pages < 2)
			return;
		?>
		<nav class="navigation paging-navigation" role="navigation">
			<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'kybully' ); ?></h1>
			<div class="nav-links">

					<?php if ( get_next_posts_link() ) : ?>
					<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'kybully' ) ); ?></div>
					<?php endif; ?>

					<?php if ( get_previous_posts_link() ) : ?>
					<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'kybully' ) ); ?></div>
					<?php endif; ?>

				</div>
			<!-- .nav-links -->
		</nav>
		<!-- .navigation -->
	<?php
		wp_reset_postdata();
	}
endif;

if (! function_exists ( 'kybully_post_nav' )) :
	/**
	 * Display navigation to next/previous post when applicable.
	 *
	 * @since KYBULLY 1.0
	 *       
	 */
	function kybully_post_nav() {
		global $post;
		
		// Don't print empty markup if there's nowhere to navigate.
		$previous = (is_attachment ()) ? get_post ( $post->post_parent ) : get_adjacent_post ( false, '', true );
		$next = get_adjacent_post ( false, '', false );
		
		if (! $next && ! $previous)
			return;
		?>
<nav class="navigation post-navigation" role="navigation">
	<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'kybully' ); ?></h1>
	<div class="nav-links">

			<?php previous_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'kybully' ) ); ?>
			<?php next_post_link( '%link', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'kybully' ) ); ?>

		</div>
	<!-- .nav-links -->
</nav>
<!-- .navigation -->
<?php
	}


endif;

if (! function_exists ( 'kybully_entry_meta' )) :
	/**
	 * Print HTML with meta information for current post: categories, tags, permalink, author, and date.
	 *
	 * Create your own kybully_entry_meta() to override in a child theme.
	 *
	 * @since KYBULLY 1.0
	 */
	function kybully_entry_meta() {
		if (is_sticky () && is_home () && ! is_paged ())
			echo '<span class="featured-post">' . __ ( 'Sticky', 'kybully' ) . '</span>';
		
		if (! has_post_format ( 'link' ) && 'post' == get_post_type ())
			kybully_entry_date ();
			
			// Translators: used between list items, there is a space after the comma.
		$categories_list = get_the_category_list ( __ ( ', ', 'kybully' ) );
		if ($categories_list) {
			echo '<span class="categories-links">' . $categories_list . '</span>';
		}
		
		// Translators: used between list items, there is a space after the comma.
		$tag_list = get_the_tag_list ( '', __ ( ', ', 'kybully' ) );
		if ($tag_list) {
			echo '<span class="tags-links">' . $tag_list . '</span>';
		}
		
		// Post author
		if ('post' == get_post_type ()) {
			printf ( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>', esc_url ( get_author_posts_url ( get_the_author_meta ( 'ID' ) ) ), esc_attr ( sprintf ( __ ( 'View all posts by %s', 'kybully' ), get_the_author () ) ), get_the_author () );
		}
	}


endif;

if (! function_exists ( 'kybully_entry_date' )) :
	/**
	 * Print HTML with date information for current post.
	 *
	 * Create your own kybully_entry_date() to override in a child theme.
	 *
	 * @since KYBULLY 1.0
	 *       
	 * @param boolean $echo
	 *        	(optional) Whether to echo the date. Default true.
	 * @return string The HTML-formatted post date.
	 */
	function kybully_entry_date($echo = true) {
		if (has_post_format ( array (
				'chat',
				'status' 
		) ))
			$format_prefix = _x ( '%1$s on %2$s', '1: post format name. 2: date', 'kybully' );
		else
			$format_prefix = '%2$s';
		
		$date = sprintf ( '<span class="date"><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a></span>', esc_url ( get_permalink () ), esc_attr ( sprintf ( __ ( 'Permalink to %s', 'kybully' ), the_title_attribute ( 'echo=0' ) ) ), esc_attr ( get_the_date ( 'c' ) ), esc_html ( sprintf ( $format_prefix, get_post_format_string ( get_post_format () ), get_the_date () ) ) );
		
		if ($echo)
			echo $date;
		
		return $date;
	}


endif;

if (! function_exists ( 'kybully_the_attached_image' )) :
	/**
	 * Print the attached image with a link to the next attached image.
	 *
	 * @since KYBULLY 1.0
	 */
	function kybully_the_attached_image() {
		/**
		 * Filter the image attachment size to use.
		 *
		 * @since Twenty thirteen 1.0
		 *       
		 * @param array $size
		 *        	{
		 *        	@type int The attachment height in pixels.
		 *        	@type int The attachment width in pixels.
		 *        	}
		 */
		$attachment_size = apply_filters ( 'kybully_attachment_size', array (
				724,
				724 
		) );
		$next_attachment_url = wp_get_attachment_url ();
		$post = get_post ();
		
		/*
		 * Grab the IDs of all the image attachments in a gallery so we can get the URL
		 * of the next adjacent image in a gallery, or the first image (if we're
		 * looking at the last image in a gallery), or, in a gallery of one, just the
		 * link to that image file.
		 */
		$attachment_ids = get_posts ( array (
				'post_parent' => $post->post_parent,
				'fields' => 'ids',
				'numberposts' => - 1,
				'post_status' => 'inherit',
				'post_type' => 'attachment',
				'post_mime_type' => 'image',
				'order' => 'ASC',
				'orderby' => 'menu_order ID' 
		) );
		
		// If there is more than 1 attachment in a gallery...
		if (count ( $attachment_ids ) > 1) {
			foreach ( $attachment_ids as $attachment_id ) {
				if ($attachment_id == $post->ID) {
					$next_id = current ( $attachment_ids );
					break;
				}
			}
			
			// get the URL of the next image attachment...
			if ($next_id)
				$next_attachment_url = get_attachment_link ( $next_id );
				
				// or get the URL of the first image attachment.
			else
				$next_attachment_url = get_attachment_link ( array_shift ( $attachment_ids ) );
		}
		
		printf ( '<a href="%1$s" title="%2$s" rel="attachment">%3$s</a>', esc_url ( $next_attachment_url ), the_title_attribute ( array (
				'echo' => false 
		) ), wp_get_attachment_image ( $post->ID, $attachment_size ) );
	}


endif;

/**
 * Return the post URL.
 *
 * @uses get_url_in_content() to get the URL in the post meta (if it exists) or
 *       the first link found in the post content.
 *      
 *       Falls back to the post permalink if no URL is found in the post.
 *      
 * @since KYBULLY 1.0
 *       
 * @return string The Link format URL.
 */
function kybully_get_link_url() {
	$content = get_the_content ();
	$has_url = get_url_in_content ( $content );
	
	return ($has_url) ? $has_url : apply_filters ( 'the_permalink', get_permalink () );
}

if (! function_exists ( 'kybully_excerpt_more' ) && ! is_admin ()) :
	/**
	 * Replaces "[...]" (appended to automatically generated excerpts) with .
	 *
	 * ..
	 * and a Continue reading link.
	 *
	 * @since KYBULLY 1.4
	 *       
	 * @param string $more
	 *        	Default Read More excerpt link.
	 * @return string Filtered Read More excerpt link.
	 */
	function kybully_excerpt_more($more) {
		$link = sprintf ( '<a href="%1$s" class="more-link">%2$s</a>', esc_url ( get_permalink ( get_the_ID () ) ),
			/* translators: %s: Name of current post */
			sprintf ( __ ( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'kybully' ), '<span class="screen-reader-text">' . get_the_title ( get_the_ID () ) . '</span>' ) );
		return ' &hellip; ' . $link;
	}
	add_filter ( 'excerpt_more', 'kybully_excerpt_more' );


endif;

/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Active widgets in the sidebar to change the layout and spacing.
 * 3. When avatars are disabled in discussion settings.
 *
 * @since KYBULLY 1.0
 *       
 * @param array $classes
 *        	A list of existing body class values.
 * @return array The filtered body class list.
 */
function kybully_body_class($classes) {
	if (! is_multi_author ())
		$classes [] = 'single-author';
	
	if (is_active_sidebar ( 'sidebar-2' ) && ! is_attachment () && ! is_404 ())
		$classes [] = 'sidebar';
	
	if (! get_option ( 'show_avatars' ))
		$classes [] = 'no-avatars';
	
	return $classes;
}
add_filter ( 'body_class', 'kybully_body_class' );

/**
 * Adjust content_width value for video post formats and attachment templates.
 *
 * @since KYBULLY 1.0
 */
function kybully_content_width() {
	global $content_width;
	
	if (is_attachment ())
		$content_width = 724;
	elseif (has_post_format ( 'audio' ))
		$content_width = 484;
}
add_action ( 'template_redirect', 'kybully_content_width' );

/**
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since KYBULLY 1.0
 *       
 * @param WP_Customize_Manager $wp_customize
 *        	Customizer object.
 */
function kybully_customize_register($wp_customize) {
	$wp_customize->get_setting ( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting ( 'blogdescription' )->transport = 'postMessage';
	$wp_customize->get_setting ( 'header_textcolor' )->transport = 'postMessage';
}
add_action ( 'customize_register', 'kybully_customize_register' );

/**
 * Enqueue Javascript postMessage handlers for the Customizer.
 *
 * Binds JavaScript handlers to make the Customizer preview
 * reload changes asynchronously.
 *
 * @since KYBULLY 1.0
 */

 
/* 
* Include Core fucntion file.
*/
require_once('inc/core-functions.php'); 
 