<?php
/**
 * Custom template tags for KYBULLY
 *
 * @package WordPress
 * @subpackage KYBULLY
 * @since KYBULLY 1.0
 */

if ( ! function_exists( 'kybully_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since KYBULLY 1.0
 */
function kybully_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
		'base'     => $pagenum_link,
		'format'   => $format,
		'total'    => $GLOBALS['wp_query']->max_num_pages,
		'current'  => $paged,
		'mid_size' => 1,
		'add_args' => array_map( 'urlencode', $query_args ),
		'prev_text' => __( '&larr; Previous', 'kybully' ),
		'next_text' => __( 'Next &rarr;', 'kybully' ),
	) );

	if ( $links ) :

	?>
	 <div class="pagination">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'kybully' ); ?></h1>
			<?php echo $links; ?>
	</div>
	<?php
	endif;
}
endif;

if ( ! function_exists( 'kybully_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @since KYBULLY 1.0
 */
function kybully_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}

	?>
	<?php /*?><nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'kybully' ); ?></h1>
		<div class="nav-links">
			<?php
			if ( is_attachment() ) :
				previous_post_link( '%link', __( '<span class="meta-nav">Published In</span>%title', 'kybully' ) );
			else :
				previous_post_link( '%link', __( '<span class="meta-nav">Previous Post</span>%title', 'kybully' ) );
				next_post_link( '%link', __( '<span class="meta-nav">Next Post</span>%title', 'kybully' ) );
			endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation --><?php */?>
	<?php
}
endif;

if ( ! function_exists( 'kybully_posted_on' ) ) :
/**
 * Print HTML with meta information for the current post-date/time and author.
 *
 * @since KYBULLY 1.0
 */
function kybully_posted_on() {
	if ( is_sticky() && is_home() && ! is_paged() ) {
		echo '<span class="featured-post">' . __( 'Sticky', 'kybully' ) . '</span>';
	}

	// Set up and print post meta information.
	printf( '<span class="byline"><span class="author vcard"><a class="url fn n" href="%4$s" rel="author">%5$s</a></span></span>',
		esc_url( get_permalink() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		get_the_author()
	);
}
endif;


function kybully_posted_date() {
	
	// Set up and print post meta information.
	printf( '<a href="%1$s" rel="bookmark" class="date"><time datetime="%3$s"><strong>%3$s</strong></time></a></span>',
		esc_url( get_permalink() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		get_the_author()
	);
}


/**
 * Find out if blog has more than one category.
 *
 * @since KYBULLY 1.0
 *
 * @return boolean true if blog has more than 1 category
 */
function kybully_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'kybully_category_count' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'kybully_category_count', $all_the_cool_cats );
	}

	if ( 1 !== (int) $all_the_cool_cats ) {
		// This blog has more than 1 category so kybully_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so kybully_categorized_blog should return false
		return false;
	}
}

/**
 * Flush out the transients used in kybully_categorized_blog.
 *
 * @since KYBULLY 1.0
 */
function kybully_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'kybully_category_count' );
}
add_action( 'edit_category', 'kybully_category_transient_flusher' );
add_action( 'save_post',     'kybully_category_transient_flusher' );

/**
 * Display an optional post thumbnail.
 *
 * Wraps the post thumbnail in an anchor element on index
 * views, or a div element when on single views.
 *
 * @since KYBULLY 1.0
 */
function kybully_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	if ( is_singular() ) :
	?>

	<div class="post-thumbnail">
	<?php
		if ( ( ! is_active_sidebar( 'sidebar-2' ) || is_page_template( 'page-templates/full-width.php' ) ) ) {
			the_post_thumbnail( 'kybully-full-width' );
		} else {
			the_post_thumbnail();
		}
	?>
	</div>

	<?php else : ?>

	<a class="post-thumbnail" href="<?php the_permalink(); ?>">
	<?php
		if ( ( ! is_active_sidebar( 'sidebar-2' ) || is_page_template( 'page-templates/full-width.php' ) ) ) {
			the_post_thumbnail( 'kybully-full-width' );
		} else {
			the_post_thumbnail();
		}
	?>
	</a>

	<?php endif; // End is_singular()
}
